[Scummvm-cvs-logs] SF.net SVN: scummvm: [30131] scummvm/trunk/engines/lure/intro.cpp

dreammaster at users.sourceforge.net dreammaster at users.sourceforge.net
Tue Jan 1 23:55:55 CET 2008


Revision: 30131
          http://scummvm.svn.sourceforge.net/scummvm/?rev=30131&view=rev
Author:   dreammaster
Date:     2008-01-01 14:55:54 -0800 (Tue, 01 Jan 2008)

Log Message:
-----------
Bugfix to show the final text screen correctly in EGA mode

Modified Paths:
--------------
    scummvm/trunk/engines/lure/intro.cpp

Modified: scummvm/trunk/engines/lure/intro.cpp
===================================================================
--- scummvm/trunk/engines/lure/intro.cpp	2008-01-01 20:27:40 UTC (rev 30130)
+++ scummvm/trunk/engines/lure/intro.cpp	2008-01-01 22:55:54 UTC (rev 30131)
@@ -165,9 +165,17 @@
 	} while (anim->step());
 	delete anim;
 	
-	if (!result) 
-		// Show final introduction screen
-		showScreen(0x22, 0x21, 10000);
+	if (!result) {
+		// Show final introduction animation
+		if (!isEGA)
+			showScreen(0x22, 0x21, 10000);
+		else {
+			Palette finalPalette(0x21);
+			anim = new AnimationSequence(0x22, finalPalette, false);
+			delete anim;
+			interruptableDelay(10000);
+		}
+	}
 
 	Sound.musicInterface_KillAll();
 	return false;


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list